@@ -10,6 +10,7 @@ import re
 from typing import Dict, List, Optional
 from urllib.parse import unquote, urlparse
 
+from _pytest.fixtures import FixtureRequest
 import pytest
 import requests
 from requests.adapters import BaseAdapter
@@ -117,7 +118,7 @@ def get_response_cb(
 
 
 @pytest.fixture
-def datadir(request):
+def datadir(request: FixtureRequest) -> str:
     """By default, returns the test directory's data directory.
 
     This can be overridden on a per file tree basis. Add an override
@@ -297,7 +298,7 @@ def flask_app_client(app):
 # stolen from pytest-flask, required to have url_for() working within tests
 # using flask_app_client fixture.
 @pytest.fixture(autouse=True)
-def _push_request_context(request):
+def _push_request_context(request: FixtureRequest):
     """During tests execution request context has been pushed, e.g. `url_for`,
     `session`, etc. can be used in tests as is::
 
